@@ -45,6 +45,8 @@ class MaiTai:
             print('Invalid Wavelength')
 
 
+    def On(self):
+        self.MaiTai.write('ON')
 
 
 
@@ -54,4 +56,4 @@ class MaiTai:
 if __name__=='__main__':
     MaiTai = MaiTai()
     MaiTai.__init__()
-    MaiTai.Shutter(0)
+
