@@ -5,7 +5,7 @@ Created on Tue Oct 13 16:14:23 2020
 @author: Mai Tai
 """
 
-from instruments.MaiTai import MaiTai
+from neogiinstruments.MaiTai import MaiTai
 import time
 import numpy as np
 from instruments import CRotator
